<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>FlipHorizontal</name>
    <message>
        <location filename="../FlipHorizontalInit.js" line="+2"/>
        <source>Flip Hori&amp;zontal</source>
        <translation>Odbij p&amp;oziomo</translation>
    </message>
</context>
</TS>
